# 🚀 Easy Gateway

A simple to use and lightweight API Gateway for microservice architecture.

## ✨ Features

- ✅ Easy setup via YAML
- ✅ CLI interface
- ✅ Middleware system
- ✅ Routing with prefixes
- ✅ Rate limiting
- ✅ Logging

## 📦 Install



```bash
pip install easy-gateway
```
DOCS:
[Visit](https://marklevkovich.github.io/easy-gateway-docs/)
